==> eg_stop_unloading_my_shaders-v1.1.3-fabric-mc1.21.9-sources.jar: games/enchanted/eg_stop_unloading_my_shaders/common/translations/Messages.java <==
package games.enchanted.eg_stop_unloading_my_shaders.common.translations;

import net.minecraft.class_124;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_5244;
import net.minecraft.class_8012;

public class Messages {
    public static class_2561 appendMessagePrefix(MessagePrefix messagePrefix, class_2561 message) {
        return class_2561.method_43473().method_10852(messagePrefix.getAsComponent()).method_10852(class_5244.field_41874).method_10852(message);
    }

    public static class_2561 translateWithFallback(String key, class_2561 value, String fallback) {
        return class_2561.method_48322(key, fallback, value.getString());
    }

    public static class_2561 getReloadingShadersMessage() {
        return appendMessagePrefix(Messages.MessagePrefix.INFO, class_2561.method_48321("debug.eg_stop_unloading_my_shaders.reloading_shaders", "_Reloading shaders"));
    }

    public static class_2561 getFailedToLoadPostChainMessage(String location) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.post_chain_load_error", "_Failed to load post_effect %s:", location);
    }

    public static class_2561 getCouldntFindPostChainSource(String location) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.no_post_chain_source_error", "_Couldn't find config .json for post_effect: %s", location);
    }

    public static class_2561 getFailedToLinkMessage(String pipelineLocation) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.linkage_error", "_Failed to link programs for pipeline %s:", pipelineLocation);
    }

    public static class_2561 getCouldntFindSourceMessage(String shaderType, String shaderLocation) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.no_source_error", "_Couldn't find source for %s shader: %s", shaderType, shaderLocation);
    }

    public static class_2561 getCouldntCompileShaderMessage(String shaderType, String shaderLocation) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.compilation_error", "_Couldn't compile %s shader: %s", shaderType, shaderLocation);
    }

    public static class_2561 getCouldntGetFullErrorMessage() {
        return class_2561.method_48321("debug.eg_stop_unloading_my_shaders.no_full_error", "_Couldn't get full error message");
    }

    public static class_2561 colourMessageGrey(class_2561 message) {
        return message.method_27661().method_54663(class_8012.field_45073);
    }

    public enum MessagePrefix {
        INFO("prefix.eg_stop_unloading_my_shaders.info", "_[SUMR Info]:", class_2583.field_24360.method_10982(true).method_10977(class_124.field_1054)),
        ERROR("prefix.eg_stop_unloading_my_shaders.error", "_[SUMR Error]:", class_2583.field_24360.method_10982(true).method_10977(class_124.field_1061)),
        ERROR_CONTINUATION("prefix.eg_stop_unloading_my_shaders.error_continuation", "_└", class_2583.field_24360.method_10982(true).method_10977(class_124.field_1061));

        private final String translationKey;
        private final String fallback;
        private final class_2583 style;

        MessagePrefix(String translationKey, String fallback, class_2583 style) {
            this.translationKey = translationKey;
            this.fallback = fallback;
            this.style = style;
        }

        class_2561 getAsComponent() {
            return class_2561.method_48321(translationKey, fallback).method_27696(style);
        }
    }
}

==> eg_stop_unloading_my_shaders-v1.2.1-fabric-mc1.21.11-rc2-sources.jar: games/enchanted/eg_stop_unloading_my_shaders/common/translations/Messages.java <==
package games.enchanted.eg_stop_unloading_my_shaders.common.translations;

import net.minecraft.class_124;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_5244;
import net.minecraft.class_8012;

public class Messages {
    public static class_2561 appendMessagePrefix(MessagePrefix messagePrefix, class_2561 message) {
        return class_2561.method_43473().method_10852(messagePrefix.getAsComponent()).method_10852(class_5244.field_41874).method_10852(message);
    }

    public static class_2561 translateWithFallback(String key, class_2561 value, String fallback) {
        return class_2561.method_48322(key, fallback, value.getString());
    }

    public static class_2561 getReloadingShadersMessage() {
        return appendMessagePrefix(Messages.MessagePrefix.INFO, class_2561.method_48321("debug.eg_stop_unloading_my_shaders.reloading_shaders", "_Reloading shaders"));
    }

    public static class_2561 getFailedToLoadPostChainMessage(String location) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.post_chain_load_error", "_Failed to load post_effect %s:", location);
    }

    public static class_2561 getCouldntFindPostChainSource(String location) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.no_post_chain_source_error", "_Couldn't find config .json for post_effect: %s", location);
    }

    public static class_2561 getFailedToLinkMessage(String pipelineLocation) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.linkage_error", "_Failed to link programs for pipeline %s:", pipelineLocation);
    }

    public static class_2561 getCouldntFindSourceMessage(String shaderType, String shaderLocation) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.no_source_error", "_Couldn't find source for %s shader: %s", shaderType, shaderLocation);
    }

    public static class_2561 getCouldntCompileShaderMessage(String shaderType, String shaderLocation) {
        return class_2561.method_48322("debug.eg_stop_unloading_my_shaders.compilation_error", "_Couldn't compile %s shader: %s", shaderType, shaderLocation);
    }

    public static class_2561 getCouldntGetFullErrorMessage() {
        return class_2561.method_48321("debug.eg_stop_unloading_my_shaders.no_full_error", "_Couldn't get full error message");
    }

    public static class_2561 colourMessageGrey(class_2561 message) {
        return message.method_27661().method_54663(class_8012.field_45073);
    }

    public enum MessagePrefix {
        INFO("prefix.eg_stop_unloading_my_shaders.info", "_[SUMR Info]:", class_2583.field_24360.method_10982(true).method_10977(class_124.field_1054)),
        ERROR("prefix.eg_stop_unloading_my_shaders.error", "_[SUMR Error]:", class_2583.field_24360.method_10982(true).method_10977(class_124.field_1061)),
        ERROR_CONTINUATION("prefix.eg_stop_unloading_my_shaders.error_continuation", "_└", class_2583.field_24360.method_10982(true).method_10977(class_124.field_1061)),
        SUMR("prefix.eg_stop_unloading_my_shaders.sumr", "_[SUMR]:", class_2583.field_24360.method_10982(true).method_10977(class_124.field_1054)),
        NONE();

        private final String translationKey;
        private final String fallback;
        private final class_2583 style;

        MessagePrefix(String translationKey, String fallback, class_2583 style) {
            this.translationKey = translationKey;
            this.fallback = fallback;
            this.style = style;
        }

        MessagePrefix() {
            this.translationKey = null;
            this.fallback = null;
            this.style = null;
        }

        class_2561 getAsComponent() {
            if(this == NONE) return class_2561.method_43473();
            return class_2561.method_48321(translationKey, fallback).method_27696(style);
        }
    }
}
